=== modified file 'Makefile'
--- Makefile	2006-08-11 14:38:04 +0000
+++ Makefile	2006-08-17 13:33:50 +0000
@@ -31,12 +31,12 @@
 	ctags-exuberant -e $(tag_files)
 
 
-# make bzr.exe for win32 with py2exe
-exe:
-	@echo *** Make bzr.exe
-	python setup.py py2exe > py2exe.log
-	python tools/win32/ostools.py copytodir tools/win32/start_bzr.bat win32_bzr.exe
-	python tools/win32/ostools.py copytodir tools/win32/bazaar.url win32_bzr.exe
+# Produce HTML docs to upload on Canonical server
+HTMLDIR := html_docs
+
+html-docs: docs
+	python tools/win32/ostools.py copytodir $(htm_files) doc/default.css $(HTMLDIR)
+
 
 # translate txt docs to html
 doc_dir := doc 
@@ -44,16 +44,34 @@
 htm_files := $(patsubst %.txt, %.htm, $(txt_files)) doc/bzr_man.htm
 
 %.htm: %.txt
-	rst2html.py --link-stylesheet --stylesheet=default.css $*.txt $*.htm
+	python tools/rst2html.py --link-stylesheet --stylesheet=default.css $*.txt $*.htm
 
-doc/bzr_man.txt:
+doc/bzr_man.txt: bzrlib/builtins.py \
+		 bzrlib/bundle/commands.py \
+		 bzrlib/conflicts.py \
+		 bzrlib/sign_my_commits.py \
+		 generate_docs.py \
+		 tools/doc_generate/__init__.py \
+		 tools/doc_generate/autodoc_rstx.py
 	python generate_docs.py -o doc/bzr_man.txt rstx
 
 docs: $(htm_files)
 
-copy_docs: docs
+copy-docs: docs
 	python tools/win32/ostools.py copytodir $(htm_files) doc/default.css NEWS README  win32_bzr.exe/doc
 
+# clean produced docs
+clean-docs:
+	python tools/win32/ostools.py remove doc/bzr_man.txt $(htm_files) $(HTMLDIR)
+
+
+# make bzr.exe for win32 with py2exe
+exe:
+	@echo *** Make bzr.exe
+	python setup.py py2exe > py2exe.log
+	python tools/win32/ostools.py copytodir tools/win32/start_bzr.bat win32_bzr.exe
+	python tools/win32/ostools.py copytodir tools/win32/bazaar.url win32_bzr.exe
+
 # win32 installer for bzr.exe
 installer: exe copy_docs
 	@echo *** Make windows installer
@@ -67,7 +85,7 @@
 
 
 # clean on win32 all installer-related files and directories
-clean_win32:
+clean-win32:
 	python tools/win32/ostools.py remove build
 	python tools/win32/ostools.py remove win32_bzr.exe
 	python tools/win32/ostools.py remove py2exe.log

=== added file 'tools/rst2html.py'
--- tools/rst2html.py	1970-01-01 00:00:00 +0000
+++ tools/rst2html.py	2006-08-17 12:14:57 +0000
@@ -0,0 +1,25 @@
+#!/usr/bin/env python
+
+# Author: David Goodger
+# Contact: goodger@python.org
+# Revision: $Revision: 3901 $
+# Date: $Date: 2005-09-25 17:49:54 +0200 (Sun, 25 Sep 2005) $
+# Copyright: This module has been placed in the public domain.
+
+"""
+A minimal front end to the Docutils Publisher, producing HTML.
+"""
+
+try:
+    import locale
+    locale.setlocale(locale.LC_ALL, '')
+except:
+    pass
+
+from docutils.core import publish_cmdline, default_description
+
+
+description = ('Generates (X)HTML documents from standalone reStructuredText '
+               'sources.  ' + default_description)
+
+publish_cmdline(writer_name='html', description=description)

